@@ -85,7 +85,8 @@ def optimizer_func(optimizer_x, *args, **kwargs):
 
     sim_data = instrument.run_full_instrument(foldername=settings["foldername"], mpi=settings["mpi"],
                                               increment_folder_name=True, force_compile=False,
-                                              parameters=instr_parameter_input, ncount=settings["ncount"])
+                                              gravity=settings["gravity"], parameters=instr_parameter_input,
+                                              ncount=settings["ncount"])
 
     remove_data_folder(settings["foldername"])
 
