@@ -3,8 +3,11 @@ from guide_bot.parameters.instrument_parameters import FreeInstrumentParameter
 from guide_bot.parameters.instrument_parameters import RelativeFreeInstrumentParameter
 from guide_bot.parameters.instrument_parameters import FixedInstrumentParameter
 from guide_bot.parameters.instrument_parameters import DependentInstrumentParameter
+from guide_bot.parameters.instrument_parameters import LosInstrumentParameter
 from guide_bot.parameters.constraints import Constraint
 
+from guide_bot.logic.line_of_sight import LosCalculator
+
 import random
 
 
@@ -210,7 +213,7 @@ class InstrumentParameterContainer:
 
         self.current_category = category
 
-    def set_values(self, optimizer_x):
+    def set_values(self, optimizer_x, los_calculator=None):
         """
         Sets value of all free parameters based on state selected by optimizer
 
@@ -265,7 +268,24 @@ class InstrumentParameterContainer:
             if limit < 0:
                 raise RuntimeError("Was not able to set all parameters! Is there a circular dependency?")
 
-    def extract_instrument_parameters(self, optimizer_x=None):
+        for parameter in self.other_parameters:
+            parameter.calculate()
+
+        if los_calculator is not None:
+            # Sets LosInstrumentParameters by solving line of sight problem
+            los_calculator.solve_los()
+
+            for par in self.all_parameters:
+                if isinstance(par, LosInstrumentParameter):
+                    if par.get_value() is None:
+                        if los_calculator.los_breakers[0].los_breaker_parameter is par:
+                            print("The pars are linked correctly")
+                        else:
+                            print("The pars are NOT linked correctly")
+
+                        raise RuntimeError("los calculator did not set a LosInstrumentParameter")
+
+    def extract_instrument_parameters(self, optimizer_x=None, los_calculator=None):
         """
         From optimizer state returns dictionary with parameter : value pairs
 
@@ -281,11 +301,14 @@ class InstrumentParameterContainer:
 
         optimizer_x : list of length matching number of free parameters
             Values for each free parameter in list form
+
+        los_calculator : LosCalculator object
+            LosCalculator object that solve line of sight and sets LosInstrumentParameters
         """
 
         if optimizer_x is not None:
             self.clear()
-            self.set_values(optimizer_x)
+            self.set_values(optimizer_x=optimizer_x, los_calculator=los_calculator)
 
         instrument_parameters = {}
         for par in self.all_parameters:
@@ -466,6 +489,13 @@ class InstrumentParameterContainer:
                             index = dynamic.dependent_on.index(free_par)
                             dynamic.dependent_on[index] = replacement_par
 
+    def print_free(self):
+        string = "Free and relative parameters \n"
+        for par in self.free_parameters + self.relative_parameters:
+            string += par.__repr__() + "\n"
+
+        print(string)
+
     def __repr__(self):
         """
         Method that returns string describing the InstrumentParameterContainer
