@@ -93,10 +93,12 @@ class CompareMonitorsScan(BaseInterface):
                 locked_slider.disabled = True
 
     def unlock_all_sliders(self):
-        for key in self.target_scan_sliders:
-            self.target_scan_sliders[key].disabled = False
-        for key in self.moderator_scan_sliders:
-            self.moderator_scan_sliders[key].disabled = False
+        if self.target_scan_sliders is not None:
+            for key in self.target_scan_sliders:
+                self.target_scan_sliders[key].disabled = False
+        if self.moderator_scan_sliders is not None:
+            for key in self.moderator_scan_sliders:
+                self.moderator_scan_sliders[key].disabled = False
 
     def make_dropdown_scan_par(self):
 
@@ -165,12 +167,17 @@ class CompareMonitorsScan(BaseInterface):
         guide = self.selected_guide
 
         plot_data = OrderedDict()
-        for scan_index, par_value in zip(range(len(par_values)), par_values):
+        for scan_index, par_value in enumerate(par_values):
             indices = copy.copy(base_indices)
             indices[par_index] = scan_index
             indices = tuple(indices)
 
-            label = self.target + " " +  self.scan_par  + " = " + str(par_value) + " " + self.unit
+            proposed_label = self.target + " " + self.scan_par + " = " + str(par_value) + " " + self.unit
+            label = proposed_label
+            index = 0
+            while label in plot_data:
+                label = proposed_label + " Alt" + str(index)
+                index += 1
 
             if self.scan_overview.data[guide][indices][moderator] is not None:
                 if run_name in self.scan_overview.data[guide][indices][moderator].runs:
