@@ -277,8 +277,9 @@ def normalize_brill_ref(data, ref_data, instrument, ref_instrument):
             area_ratio = mon_area/ref_mon_area
 
             # normalize pixel for pixel (always allowed, but less efficient)
-            data_object.Intensity /= ref_data_object.Intensity*area_ratio
-            data_object.Error = np.sqrt(data_object.Error**2 + ref_data_object.Error**2)
+            data_object.Error = np.sqrt((data_object.Error / data_object.Intensity) ** 2 + (ref_data_object.Error / ref_data_object.Intensity) ** 2)
+            data_object.Intensity /= ref_data_object.Intensity / area_ratio
+            data_object.Error *= data_object.Intensity
 
             normalized_monitors.append(data_object.name)
 
